==> hoteldruid-mod-de_2.3.0-1.zip: de/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Benutzerdefinierte Variable in Dokumenten"; break;
case "Variabili personalizzate":  		$messaggio = "Benutzerdefinierte Variable"; break;
case "Elimina":  				$messaggio = "L&ouml;schen"; break;
case "Aggiungi":  				$messaggio = "Hinzuf&uuml;gen"; break;
case "se":  					$messaggio = "Wenn"; break;
case "è uguale a":  				$messaggio = "ist gleich"; break;
case "è diverso da":  				$messaggio = "unterscheidet sich von"; break;
case "allora porre":  				$messaggio = "dann setze"; break;
case "uguale a":  				$messaggio = "gleich"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Neue benutzerdefinierte Variable eingef&uuml;gt"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Benutzerdefinierte Variable gel&ouml;scht"; break;
case "Nuova condizione inserita":  		$messaggio = "Neue Variable eingef&uuml;gt"; break;
case "Condizione eliminata":  			$messaggio = "Bedingung gel&ouml;scht"; break;
case "porre":  					$messaggio = "setze"; break;
case "sostituendo":  				$messaggio = "ersetzen"; break;
case "con":  					$messaggio = "mit"; break;
case "arrotondato a":  				$messaggio = "runde auf"; break;
case "e":  					$messaggio = "und"; break;
case "o":  					$messaggio = "oder"; break;
case "finale":  				$messaggio = "end"; break;
case "Modifica le condizioni applicate":  	$messaggio = "&Auml;ndere Bedingungen, die zugewiesen sind zu"; break;
case "Modifica":  				$messaggio = "&Auml;ndern"; break;
case "solo al documento":  			$messaggio = "nur f&uuml;r Dokument"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "weiteres &quot;if&quot;"; break;
case "azzera l'array":  			$messaggio = "unset array"; break;
case "Utilizza sempre":				$messaggio = "Benutze immer"; break;
case "Importa ora":				$messaggio = "Importiere jetzt"; break;
case "variabili e condizioni del documento":	$messaggio = "Variablen und Bedingungen von Dokument"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Inserted data are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "concatenato con":  			$messaggio = "concatenated with"; break;
case "allora":  				$messaggio = "then"; break;
case "uguaglia":  				$messaggio = "equate"; break;
case "concatena":  				$messaggio = "concatenate"; break;
case "troncare":  				$messaggio = "truncate"; break;
case "dopo":  					$messaggio = "after"; break;
case "caratteri":  				$messaggio = "characters"; break;
case "se mancanti riempire con":  		$messaggio = "if missing fill them with"; break;
case "la parte":  				$messaggio = "at the"; break;
case "iniziale":  				$messaggio = "beginning"; break;
case "riempiendo i mancanti con":  		$messaggio = "filling the missing ones with"; break;
case "all'inizio":  				$messaggio = "at the beginning"; break;
case "alla fine":  				$messaggio = "at the end"; break;
case "Array personalizzati":  			$messaggio = "Custom arrays"; break;
case "Array della variabile":  			$messaggio = "Array of variable"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Initial values to be assigned to the array"; break;
case "Nessun valore predefinito":  		$messaggio = "No initial values"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
case "una lista di valori predefiniti":  	$messaggio = "a list of predefined values"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "in repetitions only reservations in evaluated date are considered"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Conditions</b> applied"; break;
case "a tutti i documenti":  			$messaggio = "to all documents"; break;
case "al documento":  				$messaggio = "to document"; break;
case "Array personalizzato eliminato":  	$messaggio = "Custom array deleted"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "New custom array inserted"; break;
case "azzera l'array":  			$messaggio = "unset array"; break;
case "non processare le condizioni successive":	$messaggio = "do not evaluate the subsequent conditions"; break;
case "è maggiore di":  				$messaggio = "is greater than"; break;
case "è minore di":  				$messaggio = "is less than"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "only when starting repetitions of reservations"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "in all repetitons of rerservations"; break;
case "Modifica il documento":  			$messaggio = "Modify document"; break;
case "nuova condizione":  			$messaggio = "new condtition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "solo all'inizio del documento":  		$messaggio = "only at the beginning of the document"; break;
case "sempre":  				$messaggio = "always"; break;
case "azione":  				$messaggio = "action"; break;
case "assegna all'array":  			$messaggio = "assign to the array"; break;
case "aggiungi la nuova condizione":  		$messaggio = "add new condition"; break;
case "i valori":  				$messaggio = "the values"; break;
case "fino alla fine":  			$messaggio = "until the end"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "until next &quot;resume&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "resume evaluating the subsequent conditions"; break;
case "se precedentemente interrotte":  		$messaggio = "if previously interrupted"; break;
case "modifica la condizione":  		$messaggio = "modify condition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "condizione modificata":  			$messaggio = "condition modified"; break;
case "annulla":  				$messaggio = "cancel"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "current variables and coditions will be deleted"; break;
case "Visualizza le condizioni del documento":	$messaggio = "view conditions of document"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
case "numero di":  				$messaggio = "the number of"; break;
case "dalla data":  				$messaggio = "from date"; break;
case "alla data":  				$messaggio = "to date"; break;
case "solo nelle ripetizioni degli ospiti":	$messaggio = "only inside repetitions of guests"; break;
case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "only inside repetitions of extra costs"; break;
case "solo nelle ripetizioni dei pagamenti":	$messaggio = "only inside repetitions of payments"; break;
case "solo nelle ripetizioni delle unità":	$messaggio = "only inside repetitions of units"; break;
case "Condizioni applicate":  			$messaggio = "Conditions applied"; break;
case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be apllied anymore in these repetitions"; break;
case "solo nelle ripetizioni dell'array":	$messaggio = "only inside repetitions of array"; break;
case "prima di con valori negativi":  		$messaggio = "before with negative values"; break;
case "prima di":  				$messaggio = "before"; break;
case "in minuscole":  				$messaggio = "in lower case"; break;
case "in maiuscole":  				$messaggio = "in upper case"; break;
case "codificato per URL":  			$messaggio = "encoded for URL"; break;
case "codificato in ASCII":  			$messaggio = "encoded in ASCII"; break;
case "in ASCII esteso":  			$messaggio = "in extended ASCII"; break;
case "codificato con MD5":  			$messaggio = "encoded with MD5"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_3.0.8-1.zip: de/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Benutzerdefinierte Variable in Dokumenten"; break;
case "Variabili personalizzate":  		$messaggio = "Benutzerdefinierte Variable"; break;
case "Elimina":  				$messaggio = "L&ouml;schen"; break;
case "Aggiungi":  				$messaggio = "Hinzuf&uuml;gen"; break;
case "se":  					$messaggio = "Wenn"; break;
case "è uguale a":  				$messaggio = "ist gleich"; break;
case "è diverso da":  				$messaggio = "unterscheidet sich von"; break;
case "allora porre":  				$messaggio = "dann setze"; break;
case "uguale a":  				$messaggio = "gleich"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Neue benutzerdefinierte Variable eingef&uuml;gt"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Benutzerdefinierte Variable gel&ouml;scht"; break;
case "Nuova condizione inserita":  		$messaggio = "Neue Variable eingef&uuml;gt"; break;
case "Condizione eliminata":  			$messaggio = "Bedingung gel&ouml;scht"; break;
case "porre":  					$messaggio = "setze"; break;
case "sostituendo":  				$messaggio = "ersetzen"; break;
case "con":  					$messaggio = "mit"; break;
case "arrotondato a":  				$messaggio = "runde auf"; break;
case "e":  					$messaggio = "und"; break;
case "o":  					$messaggio = "oder"; break;
case "finale":  				$messaggio = "end"; break;
case "Modifica le condizioni applicate":  	$messaggio = "&Auml;ndere Bedingungen, die zugewiesen sind zu"; break;
case "Modifica":  				$messaggio = "&Auml;ndern"; break;
case "solo al documento":  			$messaggio = "nur f&uuml;r Dokument"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "weiteres &quot;if&quot;"; break;
case "azzera l'array":  			$messaggio = "unset array"; break;
case "Utilizza sempre":				$messaggio = "Benutze immer"; break;
case "Importa ora":				$messaggio = "Importiere jetzt"; break;
case "variabili e condizioni del documento":	$messaggio = "Variablen und Bedingungen von Dokument"; break;
case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be apllied anymore in these repetitions"; break;
case "a":  					$messaggio = "to"; break;
case "Modifica Variabili Documenti":  		$messaggio = "Modify Documents Variables"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Inserted data are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "concatenato con":  			$messaggio = "concatenated with"; break;
case "allora":  				$messaggio = "then"; break;
case "uguaglia":  				$messaggio = "equate"; break;
case "concatena":  				$messaggio = "concatenate"; break;
case "troncare":  				$messaggio = "truncate"; break;
case "dopo":  					$messaggio = "after"; break;
case "caratteri":  				$messaggio = "characters"; break;
case "se mancanti riempire con":  		$messaggio = "if missing fill them with"; break;
case "la parte":  				$messaggio = "at the"; break;
case "iniziale":  				$messaggio = "beginning"; break;
case "riempiendo i mancanti con":  		$messaggio = "filling the missing ones with"; break;
case "all'inizio":  				$messaggio = "at the beginning"; break;
case "alla fine":  				$messaggio = "at the end"; break;
case "Array personalizzati":  			$messaggio = "Custom arrays"; break;
case "Array della variabile":  			$messaggio = "Array of variable"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Initial values to be assigned to the array"; break;
case "Nessun valore predefinito":  		$messaggio = "No initial values"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
case "una lista di valori predefiniti":  	$messaggio = "a list of predefined values"; break;
case "separati da virgole":  			$messaggio = "comma separated"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "in repetitions only reservations in evaluated date are considered"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Conditions</b> applied"; break;
case "a tutti i documenti":  			$messaggio = "to all documents"; break;
case "al documento":  				$messaggio = "to document"; break;
case "Array personalizzato eliminato":  	$messaggio = "Custom array deleted"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "New custom array inserted"; break;
case "azzera l'array":  			$messaggio = "unset array"; break;
case "non processare le condizioni successive":	$messaggio = "do not evaluate the subsequent conditions"; break;
case "è maggiore di":  				$messaggio = "is greater than"; break;
case "è minore di":  				$messaggio = "is less than"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "only when starting repetitions of reservations"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "in all repetitons of rerservations"; break;
case "Modifica il documento":  			$messaggio = "Modify document"; break;
case "nuova condizione":  			$messaggio = "new condtition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "solo all'inizio del documento":  		$messaggio = "only at the beginning of the document"; break;
case "sempre":  				$messaggio = "always"; break;
case "azione":  				$messaggio = "action"; break;
case "assegna all'array":  			$messaggio = "assign to the array"; break;
case "aggiungi la nuova condizione":  		$messaggio = "add new condition"; break;
case "i valori":  				$messaggio = "the values"; break;
case "fino alla fine":  			$messaggio = "until the end"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "until next &quot;resume&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "resume evaluating the subsequent conditions"; break;
case "se precedentemente interrotte":  		$messaggio = "if previously interrupted"; break;
case "modifica la condizione":  		$messaggio = "modify condition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "condizione modificata":  			$messaggio = "condition modified"; break;
case "annulla":  				$messaggio = "cancel"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "current variables and coditions will be deleted"; break;
case "Visualizza le condizioni del documento":	$messaggio = "view conditions of document"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "non contiene":  				$messaggio = "doesn't contain"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
case "numero di":  				$messaggio = "the number of"; break;
case "dalla data":  				$messaggio = "from date"; break;
case "alla data":  				$messaggio = "to date"; break;
case "solo nelle ripetizioni degli ospiti":	$messaggio = "only inside repetitions of guests"; break;
case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "only inside repetitions of extra costs"; break;
case "solo nelle ripetizioni dei pagamenti":	$messaggio = "only inside repetitions of payments"; break;
case "solo nelle ripetizioni delle unità":	$messaggio = "only inside repetitions of units"; break;
case "Condizioni applicate":  			$messaggio = "Conditions applied"; break;
case "solo nelle ripetizioni dell'array":	$messaggio = "only inside repetitions of array"; break;
case "prima di con valori negativi":  		$messaggio = "before with negative values"; break;
case "prima di":  				$messaggio = "before"; break;
case "in minuscole":  				$messaggio = "in lower case"; break;
case "in maiuscole":  				$messaggio = "in upper case"; break;
case "codificato per URL":  			$messaggio = "encoded for URL"; break;
case "codificato in ASCII":  			$messaggio = "encoded in ASCII"; break;
case "in ASCII esteso":  			$messaggio = "in extended ASCII"; break;
case "codificato con MD5":  			$messaggio = "encoded with MD5"; break;
case "solo nelle ripetizioni dei documenti salvati":	$messaggio = "only inside repetitions of saved documents"; break;
case "Condizioni eliminate":  			$messaggio = "Deleted conditions"; break;
case "tutti i documenti":  			$messaggio = "all documents"; break;
case "documento":  				$messaggio = "document"; break;
case "anche condizioni":  			$messaggio = "also conditions"; break;
case "codif. in base64":  			$messaggio = "encoded to base64"; break;
case "decodif. da base64":  			$messaggio = "dec. from base64"; break;
case "codif. in HTML":  			$messaggio = "encoded to HTML"; break;
case "decodif. da HTML":  			$messaggio = "dec. from HTML"; break;
case "da base":  				$messaggio = "from base"; break;
case "codificato in MIME base64":  		$messaggio = "encoded to MIME base64"; break;
case "decodificato da MIME base64":  		$messaggio = "decoded from MIME base64"; break;
case "codificato in HTML":  			$messaggio = "encoded to HTML"; break;
case "decodificato da HTML":  			$messaggio = "decoded from HTML"; break;
case "convertito da base":  			$messaggio = "converted from base"; break;
case "a base":  				$messaggio = "to base"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
